;; Generated package description from windresize.el  -*- no-byte-compile: t -*-
(define-package "windresize" "0.1.0.20201128.195258" "Resize windows interactively" 'nil :url "https://elpa.gnu.org/packages/windresize.html" :keywords '("window") :authors '(("Bastien" . "bzg@gnu.org")) :maintainer '("Bastien" . "bzg@gnu.org"))
